"use client";

import Lightbox from "yet-another-react-lightbox";
import Captions from "yet-another-react-lightbox/plugins/captions";
import Thumbnails from "yet-another-react-lightbox/plugins/thumbnails";
import Counter from "yet-another-react-lightbox/plugins/counter";

import "yet-another-react-lightbox/styles.css";
import "yet-another-react-lightbox/plugins/thumbnails.css";
import "yet-another-react-lightbox/plugins/counter.css";
import "yet-another-react-lightbox/plugins/captions.css";
import Image from "next/image";
import {useState} from "react";

interface Props {
  img: any;
}

export default function Gallery({img}: Props) {
  const [open, setOpen] = useState(false);
  const [index, setIndex] = useState(0);
  const toggleOpen = (state: boolean) => () => setOpen(state);

  return (
    <section
      id="gallery"
      className="h-full lg:min-h-screen p-5 scroll-mt-20 lg:scroll-mt-28"
    >
      <div className="grid grid-rows-3 grid-flow-col gap-3 lg:gap-7 px-0 [&>*:nth-child(1)]:row-span-2 [&>*:nth-child(4)]:row-span-2 lg:[&>*:nth-child(5)]:row-span-2 lg:[&>*:nth-child(8)]:row-span-2 h-[360px] lg:h-screen">
        {img.slice(0, 8).map((item: any, idx: number) => (
          <div
            key={idx}
            className={` ${
              idx < 4 ? "block" : "hidden lg:block"
            } cursor-pointer`}
            onClick={() => {
              setIndex(idx), setOpen(true);
            }}
          >
            <Image
              src={item.image}
              alt='Villa Batu'
              width={1500}
              height={1000}
              priority
              className="w-full h-full object-center object-cover"
            />
          </div>
        ))}
      </div>
      <Lightbox
        index={index}
        open={open}
        close={toggleOpen(false)}
        plugins={[Thumbnails, Captions, Counter]}
        slides={img.map((item: any, idx: number) => ({
          src: item.image,
          key: idx,
        }))}
        counter={{container: {style: {top: "unset", bottom: 0}}}}
        controller={{closeOnPullDown: true, closeOnBackdropClick: true}}
      />
    </section>
  );
}
